/* Copyright (C) 2006 P.L. Lucas
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA. 
 */

#include "mainwindow.h"

MainWindow::MainWindow(QWidget *parent):QMainWindow(parent)
{
	setWindowTitle("QtOctave");
	resize(QSize(503, 418).expandedTo(minimumSizeHint()));
	
	//Se inicializan las acciones
	
	actionOpen = new QAction(this);
	actionOpen->setIcon(QIcon(QString(ICON_PATH)+"/images/konsole.png"));
	actionOpen->setText(QApplication::tr("Open"));
	
	actionOctave_help = new QAction(this);
	actionOctave_help->setIcon(QIcon(QString(ICON_PATH)+"/images/help.png"));
	actionOctave_help->setText(QApplication::tr("Octave help"));
	
	actionTable = new QAction(this);
	actionTable->setIcon(QIcon(QString(ICON_PATH)+"/images/table.png"));
	actionTable->setText(QApplication::tr("Table"));
	
	actionEditor= new QAction(this);
	actionEditor->setIcon(QIcon(QString(ICON_PATH)+"/images/xedit.png"));
	actionEditor->setText(QApplication::tr("Open editor"));
	
	//Matrix actions
	
	actionInverse = new QAction(this);
	actionInverse->setText(QApplication::tr("Inverse"));
	
	actionDeterminant = new QAction(this);
	actionDeterminant->setText(QApplication::tr("Determinant"));
	
	actionEigenvalues = new QAction(this);
	actionEigenvalues->setText(QApplication::tr("Eigenvalues and eigenvectors"));
	
	actionTranspose = new QAction(this);
	actionTranspose->setText(QApplication::tr("Transpose"));
	
	actionSubmatrix = new QAction(this);
	actionSubmatrix->setText(QApplication::tr("Submatrix"));
	
	actionMean = new QAction(this);
	actionMean->setText(QApplication::tr("Mean"));
	
	actionMedian = new QAction(this);
	actionMedian->setText(QApplication::tr("Median"));
	
	actionStd = new QAction(this);
	actionStd->setText(QApplication::tr("Standard Deviation"));
	
	actionCov = new QAction(this);
	actionCov->setText(QApplication::tr("Covariance"));
	
	actionCorrcoef = new QAction(this);
	actionCorrcoef->setText(QApplication::tr("Correlation Coefficient"));
	
	//Plot actions
	
	actionPlot = new QAction(this);
	actionPlot->setText(QApplication::tr("Plot"));
	
	actionPolar = new QAction(this);
	actionPolar->setText(QApplication::tr("Polar"));
	
	actionSemilogy = new QAction(this);
	actionSemilogy->setText(QApplication::tr("Log scale for the y axis"));
	
	actionSemilogx = new QAction(this);
	actionSemilogx->setText(QApplication::tr("Log scale for the x axis"));
	
	actionLogLog = new QAction(this);
	actionLogLog->setText(QApplication::tr("Log scale for the x and y axis"));
	
	actionAxis = new QAction(this);
	actionAxis->setText(QApplication::tr("Axis scale"));
	
	actionTitleLabel = new QAction(this);
	actionTitleLabel->setText(QApplication::tr("Title and labels"));
	
	actionToEPS  = new QAction(this);
	actionToEPS->setText(QApplication::tr("EPS"));
	
	actionToPDF  = new QAction(this);
	actionToPDF->setText(QApplication::tr("PDF"));
	
	actionToPNG  = new QAction(this);
	actionToPNG->setText(QApplication::tr("PNG"));
	
	//Config actions
	actionGeneralConfig  = new QAction(this);
	actionGeneralConfig->setText(QApplication::tr("General configuration"));
	
	//Se crea el QWorkspace o rea de trabajo
	
	work_space=new QWorkspace(this);
	work_space->setScrollBarsEnabled (true);
	work_space->show();
	setCentralWidget(work_space);
	
	//Se crean los mens
	
	menubar = new QMenuBar(this);
	//menubar->setGeometry(QRect(0, 0, 503, 29));
	
	menuFile = new QMenu(menubar);
	menuFile->setTitle(QApplication::tr("File"));
	
	menuEdit = new QMenu(menubar);
	menuEdit->setTitle(QApplication::tr("Edit"));
	
	menuHelp = new QMenu(menubar);
	menuHelp->setTitle(QApplication::tr("Help"));
	
	menuData = new QMenu(menubar);
	menuData->setTitle(QApplication::tr("Data"));
	
	menuMatrix = new QMenu(menubar);
	menuMatrix->setTitle(QApplication::tr("Matrix"));
	
	menuStatistics= new QMenu(menubar);
	menuStatistics->setTitle(QApplication::tr("Statistics"));
	
	menuPlot= new QMenu(menubar);
	menuPlot->setTitle(QApplication::tr("Plot"));
	
	menuExport= new QMenu(menuPlot);
	menuExport->setTitle(QApplication::tr("Export to..."));
	
	menu2DPlot= new QMenu(menuPlot);
	menu2DPlot->setTitle(QApplication::tr("2D..."));
	
	menuConfig= new QMenu(menubar);
	menuConfig->setTitle(QApplication::tr("Config"));
	
	setMenuBar(menubar);
	
	//Se crea la barra de estado
	
	statusbar = new QStatusBar(this);
	//statusbar->setGeometry(QRect(0, 396, 503, 22));
	setStatusBar(statusbar);
	
	//Se crea la barra de herramientas
	
	toolBar = new QToolBar(this);
	toolBar->setOrientation(Qt::Horizontal);
	addToolBar(static_cast<Qt::ToolBarArea>(4), toolBar);
	
	//Se construyen los mens
	
	show_menu_base();
	
	//Se aaden los elementos a la barra de herramientas
	
	toolBar->addAction(actionOpen);
	toolBar->addAction(actionEditor);
	toolBar->addAction(actionTable);
	toolBar->addAction(actionOctave_help);
}

QAction *MainWindow::createAction(QString action_name, const char *name, QString icon)
{
	if( actions.contains(action_name) ) return actions[action_name];
	QAction *a = new QAction(this);
	if( !icon.isEmpty() ) a->setIcon(QIcon(icon));
	a->setText(QApplication::tr(name));
	actions[action_name]=a;
	return a;
}

void MainWindow::clear_menu()
{
	menubar->clear();
}

void MainWindow::show_menu_base()
{
	menubar->addAction(menuFile->menuAction());
	menubar->addAction(menuEdit->menuAction());
	menubar->addAction(menuData->menuAction());
	menubar->addAction(menuMatrix->menuAction());
	menubar->addAction(menuStatistics->menuAction());
	menubar->addAction(menuPlot->menuAction());
	menubar->addAction(menuConfig->menuAction());
	menubar->addAction(menuHelp->menuAction());
	menuFile->addAction(actionOpen);
	menuFile->addAction(actionEditor);
	menuHelp->addAction(actionOctave_help);
	menuData->addAction(actionTable);
	menuMatrix->addAction(actionDeterminant);
	menuMatrix->addAction(actionEigenvalues);
	menuMatrix->addAction(actionInverse);
	menuMatrix->addAction(actionTranspose);
	menuMatrix->addAction(actionSubmatrix);
	menuStatistics->addAction(actionMean);
	menuStatistics->addAction(actionMedian);
	menuStatistics->addAction(actionStd);
	menuStatistics->addAction(actionCov);
	menuStatistics->addAction(actionCorrcoef);
	menuPlot->addAction(menuExport->menuAction());
	menuPlot->addAction(menu2DPlot->menuAction());
	menu2DPlot->addAction(actionPlot);
	menu2DPlot->addAction(actionPolar);
	menu2DPlot->addAction(actionLogLog);
	menu2DPlot->addAction(actionSemilogy);
	menu2DPlot->addAction(actionSemilogx);
	menu2DPlot->addAction(createAction("errorbar", "Error Bars"));
	menuPlot->addAction(actionAxis);
	menuPlot->addAction(actionTitleLabel);
	menuExport->addAction(actionToEPS);
	menuExport->addAction(actionToPDF);
	menuExport->addAction(actionToPNG);
	menuConfig->addAction(actionGeneralConfig);
}
